@@ -350,11 +350,14 @@ def github_installation(
 	:param env: The Sphinx build environment.
 	"""
 
-	username = env.config.github_username
+	if "sphinx_toolbox.github" not in env.app.extensions:
+		raise ValueError("The 'sphinx_toolbox.github' is required for the :github: option but it is not enabled!")
+
+	username = getattr(env.config, "github_username", None)
 	if username is None:
 		raise ValueError("'github_username' has not been set in 'conf.py'!")
 
-	repository = env.config.github_repository
+	repository = getattr(env.config, "github_repository", None)
 	if repository is None:
 		raise ValueError("'github_repository' has not been set in 'conf.py'!")
 
@@ -539,7 +542,9 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	# this package
 	from sphinx_toolbox import __version__
 
-	app.setup_extension("sphinx_tabs.tabs")
+	if "sphinx_inline_tabs" not in getattr(app, "extensions", ()):
+		app.setup_extension("sphinx_tabs.tabs")
+
 	app.setup_extension("sphinx-prompt")
 
 	app.add_config_value("conda_channels", [], "env", types=[list])
